﻿USE [CTMDB]
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

----------------------------------------------------------------
--  端末IDに一致したデータを削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCEXCEPTDEVICE')
	DROP PROCEDURE [CTMDBS].[PROCEXCEPTDEVICE]
GO

CREATE PROCEDURE [CTMDBS].[PROCEXCEPTDEVICE]
	@ID		int
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCEXCEPTDEVICE] 開始';
	PRINT SYSDATETIME();

    BEGIN TRANSACTION;	-- トランザクションを開始します

		-- 端末IDに一致した端末接続状態を削除します
		DELETE FROM [CTMDBS].[CTM301] WHERE [CTMDBS].[CTM301].[DeviceID] = @ID;

		-- 端末IDに一致したタスクの実行確認情報を削除します
		DELETE FROM [CTMDBS].[CTM505] WHERE [CTMDBS].[CTM505].[DeviceID] = @ID;

		-- 端末IDに一致したタスクの実行結果情報を削除します
		DELETE FROM [CTMDBS].[CTM511] WHERE [CTMDBS].[CTM511].[DeviceID] = @ID;

		-- 端末IDに一致したタスクの実行結果詳細情報を削除します
		DELETE FROM [CTMDBS].[CTM512] WHERE [CTMDBS].[CTM512].[DeviceID] = @ID;

		-- 端末IDに一致した送信メールのルール情報を削除します
		DELETE FROM [CTMDBS].[CTM602] WHERE [CTMDBS].[CTM602].[TargetID] = @ID;

		-- 端末IDに一致した送信メール履歴情報を削除します
		DELETE FROM [CTMDBS].[CTM603] WHERE [CTMDBS].[CTM603].[TargetID] = @ID;

    COMMIT TRANSACTION;	--トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCEXCEPTDEVICE] 終了';
	PRINT SYSDATETIME();
END TRY

--例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCEXCEPTDEVICE] エラー';
	PRINT SYSDATETIME();
END CATCH;

--後処理
RETURN;
GO

----------------------------------------------------------------
--  タスクIDに一致したデータを削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELETETASK')
	DROP PROCEDURE [CTMDBS].[PROCDELETETASK]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELETETASK]
	@ID		int
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELETETASK] 開始';
	PRINT SYSDATETIME();

    BEGIN TRANSACTION;	-- トランザクションを開始します

		-- タスクIDに一致したタスク基本情報を削除します
		DELETE FROM [CTMDBS].[CTM501] WHERE [CTMDBS].[CTM501].[TaskID] = @ID;

		-- タスクIDに一致したタスク共通情報を削除します
		DELETE FROM [CTMDBS].[CTM502] WHERE [CTMDBS].[CTM502].[TaskID] = @ID;

		-- タスクIDに一致したタスク共通詳細情報を削除します
		DELETE FROM [CTMDBS].[CTM503] WHERE [CTMDBS].[CTM503].[TaskID] = @ID;
		
		-- タスクIDに一致したタスク利用用途設定を削除します
		DELETE FROM [CTMDBS].[CTM504] WHERE [CTMDBS].[CTM504].[TaskID] = @ID;

		-- タスクIDに一致したタスクの実行確認情報を削除します
		DELETE FROM [CTMDBS].[CTM505] WHERE [CTMDBS].[CTM505].[TaskID] = @ID;

		-- タスクIDに一致したタスクの実行確認情報を削除します
		DELETE FROM [CTMDBS].[CTM506] WHERE [CTMDBS].[CTM506].[TaskID] = @ID;
		
		-- タスクIDに一致したタスクの実行結果情報を削除します
		DELETE FROM [CTMDBS].[CTM511] WHERE [CTMDBS].[CTM511].[TaskID] = @ID;

		-- タスクIDに一致したタスクの実行結果詳細情報を削除します
		DELETE FROM [CTMDBS].[CTM512] WHERE [CTMDBS].[CTM512].[TaskID] = @ID;

    COMMIT TRANSACTION;	--トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELETETASK] 終了';
	PRINT SYSDATETIME();
END TRY

--例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELETETASK] エラー';
	PRINT SYSDATETIME();
END CATCH;

--後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録された端末接続状態を削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELCTM301BYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELCTM301BYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELCTM301BYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELCTM301BYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します
		PRINT '>>> 端末接続状態削除開始';
		-- 削除範囲に一致した端末接続状態を削除します
		DELETE FROM [CTMDBS].[CTM301] WHERE [CTMDBS].[CTM301].[ConnectDateTime] < @StartDate;
    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELCTM301BYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELCTM301BYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録されたWIFIアクセスポイント接続状態を削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELCTM302BYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELCTM302BYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELCTM302BYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELCTM302BYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します
		PRINT '>>> WIFIアクセスポイント接続状態削除開始';
		-- 削除範囲に一致したWIFIアクセスポイント接続状態を削除します
		DELETE FROM [CTMDBS].[CTM302] WHERE [CTMDBS].[CTM302].[ConnectDateTime] < @StartDate;
    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELCTM302BYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELCTM302BYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録されたログ記録を削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELCTM401BYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELCTM401BYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELCTM401BYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELCTM401BYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します
		PRINT '>>> ログ記録削除開始';
		-- 削除範囲に一致したログ記録を削除します
		DELETE FROM [CTMDBS].[CTM401] WHERE [CTMDBS].[CTM401].ExecDateTime < @StartDate;
    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELCTM401BYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELCTM401BYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録された接続記録を削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELCTM402BYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELCTM402BYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELCTM402BYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELCTM402BYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します
		PRINT '>>> 接続記録削除開始';
		-- 削除範囲に一致した接続記録を削除します
		DELETE FROM [CTMDBS].[CTM402] WHERE [CTMDBS].[CTM402].[ConnectDateTime] < @StartDate;
    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELCTM402BYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELCTM402BYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録された送信メール履歴を削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELCTM603BYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELCTM603BYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELCTM603BYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELCTM603BYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します
		PRINT '>>> 送信メール履歴削除開始';
		-- 削除範囲に一致した送信メール履歴情報を削除します
		DELETE FROM [CTMDBS].[CTM603] WHERE [CTMDBS].[CTM603].[SendDateTime] < @StartDate;
    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELCTM603BYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELCTM603BYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録されたタスクを削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELTASKBYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELTASKBYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELTASKBYDATE]
	@StartDate			datetime2(0)	-- 削除開始日
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELTASKBYDATE] 開始';
	PRINT SYSDATETIME();

	PRINT '>>> 削除開始日';
	PRINT @StartDate;

    BEGIN TRANSACTION;	-- トランザクションを開始します

		PRINT '>>> タスク削除開始';
		-- カーソルの値を取得する変数を宣言します
		DECLARE @W_TASKNO int;

		-- カーソル定義
		-- 削除範囲に一致したタスク登録を取得します
		DECLARE CUR_TASK CURSOR FOR
			SELECT [CTMDBS].[CTM501].[TaskID]
			FROM   [CTMDBS].[CTM501] 
			WHERE  [CTMDBS].[CTM501].[LastModifyDate] < @StartDate AND [CTMDBS].[CTM501].[DeletedFlag] = 1;

		-- カーソルをオープンします
		OPEN CUR_TASK;

		-- 最初の1行目を取得して変数へ値をセットします
		FETCH NEXT FROM CUR_TASK
		INTO @W_TASKNO;

		-- データの行数分ループ処理を実行します
		WHILE @@FETCH_STATUS = 0
		BEGIN
			-- TaskIDに一致したタスク共通設定を削除します
			DELETE FROM [CTMDBS].[CTM502] WHERE [CTMDBS].[CTM502].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク共通詳細設定を削除します
			DELETE FROM [CTMDBS].[CTM503] WHERE [CTMDBS].[CTM503].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク利用用途設定を削除します
			DELETE FROM [CTMDBS].[CTM504] WHERE [CTMDBS].[CTM504].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク実行確認を削除します
			DELETE FROM [CTMDBS].[CTM505] WHERE [CTMDBS].[CTM505].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク機種モデル設定を削除します
			DELETE FROM [CTMDBS].[CTM506] WHERE [CTMDBS].[CTM506].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク実行結果を削除します
			DELETE FROM [CTMDBS].[CTM511] WHERE [CTMDBS].[CTM511].[TaskID] = @W_TASKNO;

			-- TaskIDに一致したタスク実行結果詳細を削除します
			DELETE FROM [CTMDBS].[CTM512] WHERE [CTMDBS].[CTM512].[TaskID] = @W_TASKNO;

			-- 次の行のデータを取得して変数へ値をセットします
			FETCH NEXT FROM CUR_TASK
			INTO @W_TASKNO;
		END

		-- カーソルを閉じます
		CLOSE CUR_TASK;
		DEALLOCATE CUR_TASK;

		PRINT '>>> タスク登録削除開始';
		-- 削除範囲に一致したタスク登録を削除します
		DELETE FROM [CTMDBS].[CTM501] WHERE [CTMDBS].[CTM501].[LastModifyDate] < @StartDate AND [CTMDBS].[CTM501].[DeletedFlag] = 1;

		-- カーソルの値を取得する変数を宣言します
		DECLARE @W_DEVICEID int;

		-- カーソル定義
		-- 削除範囲に一致したタスク実行結果を取得します
		DECLARE CUR_DEVICE CURSOR FOR
			SELECT [CTMDBS].[CTM511].[TaskID], [CTMDBS].[CTM511].[DeviceID]
			FROM   [CTMDBS].[CTM511] 
			WHERE  [CTMDBS].[CTM511].[LastModifyDate] < @StartDate AND [CTMDBS].[CTM511].[DeletedFlag] = 1;

		-- カーソルをオープンします
		OPEN CUR_DEVICE;

		-- 最初の1行目を取得して変数へ値をセットします
		FETCH NEXT FROM CUR_DEVICE
		INTO @W_TASKNO, @W_DEVICEID;

		-- データの行数分ループ処理を実行します
		WHILE @@FETCH_STATUS = 0
		BEGIN
			-- TaskID と DeviceID に一致したタスク実行確認を削除します
			DELETE FROM [CTMDBS].[CTM505] WHERE [CTMDBS].[CTM505].[TaskID] = @W_TASKNO AND [CTMDBS].[CTM505].[DeviceID] = @W_DEVICEID;

			-- TaskID と DeviceID に一致したタスク実行結果を削除します
			DELETE FROM [CTMDBS].[CTM511] WHERE [CTMDBS].[CTM511].[TaskID] = @W_TASKNO AND [CTMDBS].[CTM511].[DeviceID] = @W_DEVICEID;

			-- TaskID と DeviceID に一致したタスク実行結果詳細を削除します
			DELETE FROM [CTMDBS].[CTM512] WHERE [CTMDBS].[CTM512].[TaskID] = @W_TASKNO AND [CTMDBS].[CTM512].[DeviceID] = @W_DEVICEID;

			-- 次の行のデータを取得して変数へ値をセットします
			FETCH NEXT FROM CUR_DEVICE
			INTO @W_TASKNO, @W_DEVICEID;
		END

		-- カーソルを閉じます
		CLOSE CUR_DEVICE;
		DEALLOCATE CUR_DEVICE;

		PRINT '>>> タスク実行結果削除開始';
		-- 削除範囲に一致したタスク実行結果を削除します
		DELETE FROM [CTMDBS].[CTM511] WHERE [CTMDBS].[CTM511].[LastModifyDate] < @StartDate AND [CTMDBS].[CTM511].[DeletedFlag] = 1;

		PRINT '>>> タスク実行確認削除開始';
		-- 削除範囲に一致したタスク実行確認を削除します
		DELETE FROM [CTMDBS].[CTM505] WHERE [CTMDBS].[CTM505].[LastModifyDate] < @StartDate AND [CTMDBS].[CTM505].[DeletedFlag] = 1;

    COMMIT TRANSACTION;	-- トランザクションを確定します

	PRINT '>>> [CTMDBS].[PROCDELTASKBYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    ROLLBACK TRANSACTION;	-- トランザクションを取り消します
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELTASKBYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日付以前に記録されたデータを削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELDATABYDATE')
	DROP PROCEDURE [CTMDBS].[PROCDELDATABYDATE]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELDATABYDATE]
	@StartDate			datetime2(0),	-- 削除開始日
	@Terminal			bit = 1,		-- 端末状態監視
	@WifiAccesspoint	bit = 1,		-- WiFiアクセスポイント状態監視
	@Mail				bit = 1,		-- メール送信結果
	@Log				bit = 1,		-- ログ
	@DeleteTask			bit = 1			-- 削除タスク
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELDATABYDATE] 開始';
	PRINT SYSDATETIME();

	-- 削除範囲を取得します（時分秒が０なので１日追加する）
	SELECT @StartDate = DATEADD(day, 1, @StartDate);
	PRINT '>>> 削除開始日';
	PRINT @StartDate;

	IF @Terminal = 1
	BEGIN
		-- 削除範囲に一致した端末接続状態を削除します
		EXEC [CTMDBS].[PROCDELCTM301BYDATE] @StartDate;
	END

	IF @WifiAccesspoint = 1
	BEGIN
		-- 削除範囲に一致したWIFIアクセスポイント接続状態を削除します
		EXEC [CTMDBS].[PROCDELCTM302BYDATE] @StartDate;
	END

	IF @Mail = 1
	BEGIN
		-- 削除範囲に一致した送信メール履歴情報を削除します
		EXEC [CTMDBS].[PROCDELCTM603BYDATE] @StartDate;
	END

	IF @Log = 1
	BEGIN
		-- 削除範囲に一致したログ記録を削除します
		EXEC [CTMDBS].[PROCDELCTM401BYDATE] @StartDate;

		-- 削除範囲に一致した接続記録を削除します
		EXEC [CTMDBS].[PROCDELCTM402BYDATE] @StartDate;
	END

	IF @DeleteTask = 1
	BEGIN
		-- 削除範囲に一致したタスクを削除します
		EXEC [CTMDBS].[PROCDELTASKBYDATE] @StartDate;
	END

	PRINT '>>> [CTMDBS].[PROCDELDATABYDATE] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELDATABYDATE] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO

----------------------------------------------------------------
--  引数で指定した日数以前に記録されたデータを削除
----------------------------------------------------------------
IF EXISTS (SELECT * FROM sys.objects WHERE type = 'P' AND name = 'PROCDELDATABYDAYINTERVAL')
	DROP PROCEDURE [CTMDBS].[PROCDELDATABYDAYINTERVAL]
GO

CREATE PROCEDURE [CTMDBS].[PROCDELDATABYDAYINTERVAL]
	@DayInterval		int,			-- 削除日の間隔
	@Terminal			bit = 1,		-- 端末状態監視
	@WifiAccesspoint	bit = 1,		-- WiFiアクセスポイント状態監視
	@Mail				bit = 1,		-- メール送信結果
	@Log				bit = 1,		-- ログ
	@DeleteTask			bit = 1			-- 削除タスク
AS
BEGIN TRY
	PRINT '>>> [CTMDBS].[PROCDELDATABYDAYINTERVAL] 開始';
	PRINT SYSDATETIME();

	-- 変数を宣言します
	DECLARE @StartDate		datetime2(0)	-- 削除開始日
	DECLARE @Interval		int				-- 間隔

	-- 過去日付間隔を取得します
	SELECT @Interval = (ABS(@DayInterval) * -1);

	-- 削除開始日を取得します
	SELECT @StartDate = DATEADD(day, @Interval, SYSDATETIME());

	-- 削除を実行します
	EXEC [CTMDBS].[PROCDELDATABYDATE] @StartDate, @Terminal, @WifiAccesspoint, @Mail, @Log, @DeleteTask;

	PRINT '>>> [CTMDBS].[PROCDELDATABYDAYINTERVAL] 終了';
	PRINT SYSDATETIME();
END TRY

-- 例外処理
BEGIN CATCH
    PRINT ERROR_MESSAGE();	-- エラー内容を出力します
	PRINT '>>> [CTMDBS].[PROCDELDATABYDAYINTERVAL] エラー';
	PRINT SYSDATETIME();
END CATCH;

-- 後処理
RETURN;
GO
